@@ -32,11 +32,6 @@ easyGregexpr <- function(pattern, charvector, ...) {
   return(convertMatches)
 }
 
-#R Script written by Kevin Schewior, kevin.schewior@gmx.de heavily modified by Bettina Budeus, rokkaku-fight@gmx.de
-##author<< Kevin Schewior
-#from 2010-03-22 to 2010-04-26
-#analysis of mutations in AA FASTA sequences wrt certain HLA allels / epitopes
-
 #search for "change" for points where changes are possible
 #please check before executing
 
@@ -201,10 +196,11 @@ find_epitope_in_given_sequence <- function(pos.epitope, matrix.only.pvals.above.
 test_for_occurence <- function(pos.epitope, min, max, seq, allel, original_position){
 	eppi <- gsub("[(|)]", "", pos.epitope)
 	result_array <- c()
-	test.str <- as.character(subseq(seq, min, max))
+	test.str <- as.character(seq)#as.character(subseq(seq, min, max))
 	corrected.pos.epitope <- gsub("[x]","[A-Z]",eppi)
 	if (!is.null(easyGregexpr(corrected.pos.epitope,test.str))){
 		list.of.matches <- easyGregexpr(corrected.pos.epitope,test.str)
+	#	print (list.of.matches)
 		for (i in 1:nrow(list.of.matches)){
 			start <- list.of.matches[i, 2]
 			end <- list.of.matches[i, 3]
@@ -214,16 +210,24 @@ test_for_occurence <- function(pos.epitope, min, max, seq, allel, original_posit
 		create_pos_epi_csv(result_array, seq, pos.epitope, allel, original_position, test.str)
 		
 	}
-	#print (result_array)
 	return (result_array)
 }
 
 #creates plot data for possible epitopes from list with min, max values
 create_pos_epi_plot <- function(pos.epitope_list, min_FASTA_length){
 	plot <- c()
+	starting <- FALSE
 	for (i in 1:min_FASTA_length){
-		if (any(pos.epitope_list == i)){
-			plot <- c(plot, 0.99)
+		if (any(pos.epitope_list == i) & !starting){
+			starting <- TRUE
+			plot <- c(plot, 1)
+		}
+		else if (any(pos.epitope_list == i) & starting){
+			plot <- c(plot, 1)
+			starting <- FALSE
+		}
+		else if (starting){
+			plot <- c(plot, 1)
 		}
 		else{
 			plot <- c(plot, 0)
@@ -285,31 +289,26 @@ assocpoint <- structure(function(#Find possible epitopes
 	## Please consider that you have to use the dna/aa switch depending on your data!
 	##seealso<< \code{\link{check_for_pos_epi_mut_core}}
 	##note<< If a patient has a homozygot HLA Allel, then please change the second one to "00" (without ") instead!
-	path_to_file_s = NULL,
+	path_to_file_sequence_alignment = NULL,
 	### a FASTA file with sequence data. Homzygot patiens have to have a 00 instead of the HLA typeFor reference please look in
 	### example file.
-	path_to_file_p = NULL,
+	path_to_file_known_epitopes = NULL,
 	### a csv file with known epitopes. For reference please look in example file.
-	path_to_file_m = NULL,
+	path_to_file_binding_motifs = NULL,
 	### a csv file with HLA binding motifs if available. For reference please look in example file.
-	save_name,
+	save_name_pdf,
 	### the file name of the result file in pdf format
 	save_name_csv, 
 	### the file name of the result file in csv format
 	dna = FALSE,
 	### if the data is in DNA or amino Acid Code
-	patnum.threshold = 1,
+	patnum_threshold = 1,
 	### the minimum number of patients of one HLA type to consider in the calculation.
-	optical.significance_level = 0.05, 
+	optical_significance_level = 0.05, 
 	### the height of the optical horizontal line in the graphical output. It should be yout chosen p-value limit, like 0.05.
-	star.significance_level = 0.001, 
+	star_significance_level = 0.001, 
 	### the height of the invisible horizontal line above which alle points are marked as stars. Should be a high p-value limit,
 	### like 0,001.
-	pot.epitope_level = 0.05, 
-	### the level below which a p-value should be consideres in the calculation of possible epitopes. 
-	### Should be the same as optical.significance_leve.
-	window_threshold = 0.05,
-	### the level below which a p-value should be consideres in the calculation of the sliding window. 
 	### Should be the same as optical.significance_leve. 
 	A11,
 	### the position of the start of the first HLA A Allel in the description block of the FASTA file.
@@ -327,23 +326,24 @@ assocpoint <- structure(function(#Find possible epitopes
 	### the position of the start of the second HLA B Allel in the description block of the FASTA file.
 	B22,
 	### the position of the end of the second HLA B Allel in the description block of the FASTA file.
-	statistical_correction = "bonferroni",
+	multiple_testing_correction = "bonferroni",
 	### the statistical correction applied to the p-values. Input can be: "holm", "hochberg", "hommel", "bonferroni", "BH", "BY", "fdr", "none".
-	with_phylogenetic_comparison = FALSE,
+	phylo_bias_check = FALSE,
 	### if the sequences with the certain trait and Amino Acid with the lowest p.value should be compared in sequence similarity with all sequences. See details.
 	matrix_for_phylo = NULL,
 	### the matrix for phylogenetic analysis. Has to be a matrix which is with this name available in the Biostrings package.
-	reference_sequence = NULL,
+	path_to_file_reference_sequence = NULL,
 	### Reference sequence for better comparison of results
-	one_ident=FALSE,
+	one_feature=FALSE,
 	### if there is only one identifier
-	window_size=9
+	window_size=9,
 	### size for the sliding window
+	epi_plot=FALSE
 	){
 	#print (reference_sequence)
 	#print (path_to_file_p)
 	#print (path_to_file_m)
-	result <- find_possible_epitopes_inner(path_to_file_s, path_to_file_p, path_to_file_m, save_name, save_name_csv, dna, patnum.threshold, optical.significance_level, star.significance_level, pot.epitope_level, window_threshold, A11, A12, A21, A22, B11, B12, B21, B22, statistical_correction, with_phylogenetic_comparison, matrix_for_phylo, reference_sequence, one_ident, window_size)
+	result <- find_possible_epitopes_inner(path_to_file_sequence_alignment, path_to_file_known_epitopes, path_to_file_binding_motifs, save_name_pdf, save_name_csv, dna, patnum_threshold, optical_significance_level, star_significance_level, optical_significance_level, optical_significance_level, A11, A12, A21, A22, B11, B12, B21, B22, multiple_testing_correction, phylo_bias_check, matrix_for_phylo, path_to_file_reference_sequence, one_feature, window_size, epi_plot)
 	return(result)
 
 },ex=function(){
@@ -373,11 +373,12 @@ assocpoint <- structure(function(#Find possible epitopes
  FALSE,
  matrix_for_phylo = NULL,
  reference_sequence = NULL,
- one_ident=FALSE,
- window_size=9)
+ one_feature=FALSE,
+ window_size=9,
+ pos_epi_plot=FALSE)
 })
 
-find_possible_epitopes_inner <- function(path_to_file_s = NULL, path_to_file_p = NULL, path_to_file_m = NULL, save_name, save_name_csv, dna = FALSE, patnum.threshold = 1, optical.significance_level = 0.05, star.significance_level = 0.001, pot.epitope_level = 0.05, window_threshold = 0.05, A11, A12, A21, A22, B11, B12, B21, B22, statistical_correction = "bonferroni", with_phylogenetic_comparison = FALSE, matrix_for_phylo = NULL, reference_sequence = NULL, one_ident, window_size){
+find_possible_epitopes_inner <- function(path_to_file_s = NULL, path_to_file_p = NULL, path_to_file_m = NULL, save_name, save_name_csv, dna = FALSE, patnum.threshold = 1, optical.significance_level = 0.05, star.significance_level = 0.001, pot.epitope_level = 0.05, window_threshold = 0.05, A11, A12, A21, A22, B11, B12, B21, B22, statistical_correction = "bonferroni", with_phylogenetic_comparison = FALSE, matrix_for_phylo = NULL, reference_sequence = NULL, one_ident, window_size, pos_epi_plot=FALSE){
 
 	if (!is.null(reference_sequence) && reference_sequence == 0){
 		reference_sequence <- NULL
@@ -455,6 +456,7 @@ if (one_ident){
   	#tropismus holds no duplicates and none which are only a letter, without number (if the type is 00)
   	#tropismus.count counts how often the certain alles is there
   	allels.all <- c(allels.all, strsplit(names(sequences)[i], ";")[[1]][2])
+	new_sequence_names <- c(new_sequence_names, strsplit(names(sequences)[i], ";")[[1]][2])
 	}
 }else{
 	for(i in 1:length(sequences)){
@@ -525,6 +527,8 @@ allels.counter <- 0
 
 sequences_names <- names(sequences)
 
+p.values.all <- c()
+
 for(allel.num in 1:length(allels)){
   	if(allels.count[allel.num]>patnum.threshold){
 		#if (allels[allel.num] == "A24"){
@@ -549,7 +553,7 @@ for(allel.num in 1:length(allels)){
     		probs2 <- c()
 		stattest <- c()
 		# for each letter in FASTA:
-    		for (j in 1:min_FASTA_length){
+   		for (j in 1:min_FASTA_length){
 			#print (j)
       			#for each point in sequence do the following:
       			#for certain allel calculate fisher's exact test's minimum p-value among the tests for all amino acids (aa/!aa ; allel/!allel)
@@ -580,20 +584,20 @@ for(allel.num in 1:length(allels)){
 				n_aa_and_h <- length(which(subset_has_allel != aa))
 				n_aa_and_n_h <- length(which(subset_not_has_allel != aa))
         			small.table = matrix(c(aa_and_h, n_aa_and_h, aa_and_n_h, n_aa_and_n_h),nrow=2)
-				####BAYES
-				if (statistical_correction == "Bayes"){					
-					I = 10000 # simulations
-					y1 <- aa_and_h
-					y2 <- n_aa_and_h
-					n1 <- aa_and_h + aa_and_n_h
-					n2 <- n_aa_and_h + n_aa_and_n_h
-
-					theta1 = rbeta(I, y1+1, (n1-y1)+1)  
-					theta2 = rbeta(I, y2+1, (n2-y2)+1)
-
-					diff = theta1-theta2  # simulated diffs
-					probs <- c(probs, mean(theta1>theta2))
-				}else{
+				####BAYES - NOT AVAILABLE YET!
+#				if (statistical_correction == "Bayes"){					
+#					I = 10000 # simulations
+#					y1 <- aa_and_h
+#					y2 <- n_aa_and_h
+#					n1 <- aa_and_h + aa_and_n_h
+#					n2 <- n_aa_and_h + n_aa_and_n_h
+#
+#					theta1 = rbeta(I, y1+1, (n1-y1)+1)  
+#					theta2 = rbeta(I, y2+1, (n2-y2)+1)
+#
+#					diff = theta1-theta2  # simulated diffs
+#					probs <- c(probs, mean(theta1>theta2))
+#				}else{
 		  			#only calculate p-values from contingency tables with row sums above threshold or zero
 		  			if(sum(small.table[1,])*sum(small.table[2,])!=0 & (sum(small.table[1,])<=rowsum.threshold | sum(small.table[2,])<=rowsum.threshold))
 					next
@@ -610,23 +614,24 @@ for(allel.num in 1:length(allels)){
 						cat((allel.num), "\t", j, "\t", (small.table[1,1]), "\t", (small.table[2,1]), "\t", (small.table[1,2]), "\t", (small.table[2,2]), "\t", aacids[k], "\t", test.result$p.value, "\n", file= "logging.csv", append=TRUE)
 					}
 					odds.ratio <- c(odds.ratio, test.result$estimate)
-				}
+#				}
        				#print(test.result)
 				aa_values <- c(aa_values, small.table[1,1])
 				aa_values2 <- c(aa_values2, small.table[2,1])
 				aa_values3 <- c(aa_values3, small.table[1,2])
 				aa_values4 <- c(aa_values4, small.table[2,2])
      			}
-			####BAYES
-			if (statistical_correction == "Bayes"){	
-				probs.max <- c(probs.max, max(probs))
-				position <- which(probs == max(probs))
-				probs.norm <- c(probs.norm, 100*max(probs))
-			}else{
+			####BAYES - NOT AVAILABLE YET
+#			if (statistical_correction == "Bayes"){	
+#				probs.max <- c(probs.max, max(probs))
+#				position <- which(probs == max(probs))
+#				probs.norm <- c(probs.norm, 100*max(probs))
+#			}else{
       				p.values.min <- c(p.values.min, 1-min(p.values))
 				position <- which(p.values == min(p.values))
 				p.values.norm <- c(p.values.norm, min(p.values))
-			}
+#			}
+			p.values.all.little <- cbind(p.values, NA)
 			if (length(position)>1){
 				random_pos <- sample(position, 1)
 				aa_1 <- c(aa_1, paste("/", aa_values[random_pos]))
@@ -636,6 +641,7 @@ for(allel.num in 1:length(allels)){
 				aa_values_m <- c(aa_values_m, aacids[random_pos])
 				aa_level <- c(aa_level, paste("/", aa_values[random_pos]))
 				odds.ratio.all <- c(odds.ratio.all, odds.ratio[random_pos])
+				p.values.all.little[random_pos, 2] <- "min"
 			}
 			else{
 				aa_1 <- c(aa_1, aa_values[position])
@@ -645,12 +651,14 @@ for(allel.num in 1:length(allels)){
 				aa_values_m <- c(aa_values_m, aacids[position])
 				aa_level <- c(aa_level, aa_values[position])
 				odds.ratio.all <- c(odds.ratio.all, odds.ratio[position])
+				p.values.all.little[position, 2] <- "min"
 			}
-			####BAYES
-			if (statistical_correction == "Bayes"){	
-					print ("Nothing here yet")
-			}else{
-				if (p.values.norm[j] <= 0.01 && with_phylogenetic_comparison){
+			p.values.all <- rbind(p.values.all, p.values.all.little)
+			####BAYES - NOT AVAILABLE YET
+#			if (statistical_correction == "Bayes"){	
+#					#print ("Nothing here yet")
+#			}else{
+				if (p.values.norm[j] <= optical.significance_level && with_phylogenetic_comparison){
 					singleAA <- as.character(subseq(StringSetsequences_p, j, j))
 					seq_number_with_AA <- which(singleAA==aa_values_m[j])
 					seq_number_without_AA <- which(singleAA!=aa_values_m[j])
@@ -673,7 +681,7 @@ for(allel.num in 1:length(allels)){
 					stattest <- c(stattest, "/")
 				}
 				#print (position)
-			}
+#			}
 
     		}
 
@@ -686,22 +694,22 @@ for(allel.num in 1:length(allels)){
 		#fill allel.epitopes2 with zeros for FASTA-length, then put max of p.values.min for all values between epitope border	
 		allel.epitopes2 <- rep(0,min_FASTA_length)
 		
-		####BAYES
-		if (statistical_correction == "Bayes"){	
-	    		if(length(allel.epitopes[,1])>0)
-			for (i in 1:length(allel.epitopes[,1])){
-        			allel.epitopes2[allel.epitopes[i,1]:allel.epitopes[i,2]] <- max(probs.max)
-			}
-			all.pvals_one_allel<-c(probs.max)
-			matrix.all.pvals_pre <- matrix(all.pvals_one_allel, ncol=1, dimnames=list(1:length(probs.max),allels[allel.num]))
-		}else{
+		####BAYES - NOT AVAILABLE YET
+#		if (statistical_correction == "Bayes"){	
+#	    		if(length(allel.epitopes[,1])>0)
+#			for (i in 1:length(allel.epitopes[,1])){
+ #       			allel.epitopes2[allel.epitopes[i,1]:allel.epitopes[i,2]] <- max(probs.max)
+#			}
+#			all.pvals_one_allel<-c(probs.max)
+#			matrix.all.pvals_pre <- matrix(all.pvals_one_allel, ncol=1, dimnames=list(1:length(probs.max),allels[allel.num]))
+#		}else{
 	    		if(length(allel.epitopes[,1])>0)
 	      		for (i in 1:length(allel.epitopes[,1])){
 				allel.epitopes2[allel.epitopes[i,1]:allel.epitopes[i,2]] <- max(p.values.min)
 			}
 			all.pvals_one_allel<-c(p.values.min)
 			matrix.all.pvals_pre <- matrix(all.pvals_one_allel, ncol=1, dimnames=list(1:length(p.values.min),allels[allel.num]))
-		}
+#		}
 		#post_production for every allel above threshold:
 		#first: create a matrix with a column for position,
 		#second: remove all rows with values beneath a certain threshold
@@ -754,8 +762,6 @@ for(allel.num in 1:length(allels)){
 				}
 			}
 
-			#für jede Zeile in matrix.only.pvals.above.threshold nachsehen ob Wert innerhalb eines der dort genannten Epitope liegt
-		
 			pos.epitope_list <- c()
 			#print (seq)
 			if ((!is.null(pos.epitopes.f.allel)) && (length(matrix.only.pvals.above.threshold)>0)){
@@ -781,69 +787,88 @@ for(allel.num in 1:length(allels)){
 			number_of_mutations_in_sequence <- c(number_of_mutations_in_sequence, ((1.0/window_size)*number_of_mutations_in_window))
 		}
 
-		####BAYES
-		if (statistical_correction == "Bayes"){	
-			highest_prob_value <- max(probs.norm)
-		}else{
+		####BAYES - NOT AVAILABLE YET
+#		if (statistical_correction == "Bayes"){	
+#			highest_prob_value <- max(probs.norm)
+#		}else{
 			lowest_p_value <- min(p.values.norm)
 			vector_for_yaxis <- get_10_based(min(p.values.norm))
-		}
+#		}
+		if (pos_epi_plot){
+			par(fig=c(0,0.75,0.55,1))#, new=TRUE)
+			if (is.null(path_to_file_m) & !is.null(path_to_file_p)){
+				plot (panel.first=
+				c(lines(allel.epitopes2, type="l", col="red")), #known epitopes in red
+				number_of_mutations_in_sequence, type="l", col = "black", main=paste(allels[allel.num],"(",allels.count[allel.num]," patient(s))",sep=""),ylab="fraction of significant p-values", xlab="", xlim=c(0, min_FASTA_length), ylim=c(0,1)) # plot for percental number of mutations in 9er
+				par(fig=c(0,1,0.6,1))
+				legend("right", c("known epitopes", paste("# mutations in ", window_size,"er \nsliding window", sep="")),lty=c(1,1,1),lwd=c(1.5,1.5,1.5),col=c("red","black"),bty="n", cex=0.8, xjust=0)
+			}else if (!is.null(path_to_file_m) & is.null(path_to_file_p)){
+				plot (panel.first=
+				c(lines(pos.epitope.plot, type="l", col = "darkgoldenrod1")), #known epitopes in red
+				number_of_mutations_in_sequence, type="l", col = "black", main=paste(allels[allel.num],"(",allels.count[allel.num]," patient(s))",sep=""),ylab="fraction of significant p-values", xlab="", xlim=c(0, min_FASTA_length), ylim=c(0,1)) # plot for percental number of mutations in 9er
+				par(fig=c(0,1,0.6,1))
+				legend("right", c("possible new epitopes", paste("# mutations in ", window_size,"er \nsliding window", sep="")),lty=c(1,1,1),lwd=c(1.5,1.5,1.5),col=c("darkgoldenrod1","black"),bty="n", cex=0.8, xjust=0)
+			}else if (is.null(path_to_file_p) & is.null(path_to_file_m)){
+				plot (number_of_mutations_in_sequence, type="l", col = "black", main=paste(allels[allel.num],"(",allels.count[allel.num]," patient(s))",sep=""),ylab="fraction of significant p-values", xlab="", xlim=c(0, min_FASTA_length)) # plot for percental number of mutations in 9er
+				par(fig=c(0,1,0.6,1))
+				legend("right", c(paste("# mutations in ", window_size,"er \nsliding window", sep="")),lty=c(1,1,1),lwd=c(1.5,1.5,1.5),col=c("black"),bty="n", cex=0.8, xjust=0)
 
-		par(fig=c(0,0.75,0.55,1))#, new=TRUE)
-		if (is.null(path_to_file_p)==FALSE){
-			plot (panel.first=
-			c(lines(allel.epitopes2, type="l", col="red"), #known epitopes in red
-			lines(pos.epitope.plot, type="l", col = "yellow")), # possible epitopes in yellow
-			number_of_mutations_in_sequence, type="l", col = "black", main=paste(allels[allel.num],"(",allels.count[allel.num]," patient(s))",sep=""),ylab="number of mutations[%]", xlab="") # plot for percental number of mutations in 9er
-			par(fig=c(0,1,0.6,1))
-			legend("right", c("known epitopes","possible new epitopes", "#mutations in 9er \nblock"),lty=c(1,1,1),lwd=c(1.5,1.5,1.5),col=c("red","yellow","black"),bty="n", cex=0.8, xjust=0)
+			}else{
+				plot (panel.first=
+				c(lines(allel.epitopes2, type="l", col="red"), #known epitopes in red
+				lines(pos.epitope.plot, type="l", col = "darkgoldenrod1")), # possible epitopes in darkgoldenrod1
+				number_of_mutations_in_sequence, type="l", col = "black", main=paste(allels[allel.num],"(",allels.count[allel.num]," patient(s))",sep=""),ylab="fraction of significant p-values", xlab="", xlim=c(0, min_FASTA_length), ylim=c(0,1)) # plot for percental number of mutations in 9er
+				par(fig=c(0,1,0.6,1))
+				legend("right", c("known epitopes","possible new epitopes", paste("# mutations in ", window_size,"er \nsliding window", sep="")),lty=c(1,1,1),lwd=c(1.5,1.5,1.5),col=c("red","darkgoldenrod1","black"),bty="n", cex=0.8, xjust=0)
+			}
+			par(fig=c(0,0.75,0.0,0.6), new=TRUE)
 		}
-		else{
-			plot (panel.first=
-			c(lines(allel.epitopes2, type="l", col="red")), #known epitopes in red
-			number_of_mutations_in_sequence, type="l", col = "black", main=paste(allels[allel.num],"(",allels.count[allel.num]," patient(s))",sep=""),ylab="number of mutations[%]", xlab="") # plot for percental number of mutations in 9er
-			par(fig=c(0,1,0.6,1))
-			legend("right", c("known epitopes","possible new epitopes", "#mutations in 9er \nblock"),lty=c(1,1,1),lwd=c(1.5,1.5,1.5),col=c("red","yellow","black"),bty="n", cex=0.8, xjust=0)
-		}
-		par(fig=c(0,0.75,0.0,0.6), new=TRUE)
-		####BAYES
-		if (statistical_correction == "Bayes"){	
-			plot(probs.norm, type="p", col="black", pch=20, ylab="p-values", xlab="")
-			#axis(side=2, at=vector_for_yaxis, labels=vector_for_yaxis)
-			corrected_opti <- optical.significance_level
-			corrected_star <- star.significance_level
-			abline(h=optical.significance_level, col = "gray60", lty=2)
-			probs.above_sig_level_norm <- probs.norm
-			probs.above_star_level_norm <- probs.norm
-			for (i in 1:length(probs.norm)){
-				if (probs.norm[i] >= (corrected_opti)){
-					if (probs.norm[i] >= (corrected_star)){
-						probs.above_star_level_norm[i] <- probs.norm[i]
-					}
-					else{
-						probs.above_sig_level_norm[i] <- probs.norm[i]
-						probs.above_star_level_norm[i] <- 0
-					}
-				}
-				else {
-					probs.above_sig_level_norm[i] <- 0
-					probs.above_star_level_norm[i] <- 0
-				}
+		####BAYES - NOT AVAILABLE YET
+#		if (statistical_correction == "Bayes"){	
+#			plot(probs.norm, type="p", col="black", pch=20, ylab="p-values", xlab="Alignment position", xlim=c(0, min_FASTA_length))
+#			#axis(side=2, at=vector_for_yaxis, labels=vector_for_yaxis)
+#			corrected_opti <- optical.significance_level
+#			corrected_star <- star.significance_level
+#			abline(h=optical.significance_level, col = "gray60", lty=2)
+#			probs.above_sig_level_norm <- probs.norm
+#			probs.above_star_level_norm <- probs.norm
+#			for (i in 1:length(probs.norm)){
+#				if (probs.norm[i] >= (corrected_opti)){
+#					if (probs.norm[i] >= (corrected_star)){
+#						probs.above_star_level_norm[i] <- probs.norm[i]
+#					}
+#					else{
+#						probs.above_sig_level_norm[i] <- probs.norm[i]
+#						probs.above_star_level_norm[i] <- 0
+#					}
+#				}
+#				else {
+#					probs.above_sig_level_norm[i] <- 0
+#					probs.above_star_level_norm[i] <- 0
+#				}
+#			}
+#			vert_lines <- which(probs.above_star_level_norm > 0)
+#			for (sp in 1:length(vert_lines)){
+#				abline(v=vert_lines[sp], col = "gray60", lty=2)
+#			}
+#			lines(probs.above_sig_level_norm, type="p", col = "red", pch=20) #points above a certain significance level
+#			lines(probs.above_star_level_norm, type="p", col = "red", pch=8) #stars above a certain significance level
+#
+#			all.pvals<-c(all.pvals,probs.norm)
+#			aa.all_level <- cbind(aa.all_level, aa_level)
+#			all.aas <- cbind(all.aas, aa_values_m)
+#			all.aa_1 <- cbind(all.aa_1, aa_1)
+#			all.aa_2 <- cbind(all.aa_2, aa_2)
+#			all.aa_3 <- cbind(all.aa_3, aa_3)
+#			all.aa_4 <- cbind(all.aa_4, aa_4)
+#			#all.odds <- cbind(all.odds, odds.ratio.all)
+#			above.star.all <- cbind(above.star.all, probs.above_star_level_norm)
+#			all.stattest <- cbind(all.stattest, stattest)
+#		}else{	
+			plot(p.values.norm, type="p", ylim=c(1.0,lowest_p_value), log="y", col="black", yaxt="n", pch=20, ylab="p-values", xlab="Alignment position", xlim=c(0, min_FASTA_length))
+			if (!pos_epi_plot){
+				mtext(paste(allels[allel.num],"(",allels.count[allel.num]," patient(s))",sep=""))
 			}
-			lines(probs.above_sig_level_norm, type="p", col = "red", pch=20) #points above a certain significance level
-			lines(probs.above_star_level_norm, type="p", col = "red", pch=8) #stars above a certain significance level
-			all.pvals<-c(all.pvals,probs.norm)
-			aa.all_level <- cbind(aa.all_level, aa_level)
-			all.aas <- cbind(all.aas, aa_values_m)
-			all.aa_1 <- cbind(all.aa_1, aa_1)
-			all.aa_2 <- cbind(all.aa_2, aa_2)
-			all.aa_3 <- cbind(all.aa_3, aa_3)
-			all.aa_4 <- cbind(all.aa_4, aa_4)
-			#all.odds <- cbind(all.odds, odds.ratio.all)
-			above.star.all <- cbind(above.star.all, probs.above_star_level_norm)
-			all.stattest <- cbind(all.stattest, stattest)
-		}else{	
-			plot(p.values.norm, type="p", ylim=c(1.0,lowest_p_value), log="y", col="black", yaxt="n", pch=20, ylab="p-values", xlab="")
 			axis(side=2, at=vector_for_yaxis, labels=vector_for_yaxis)
 			corrected_opti <- optical.significance_level
 			corrected_star <- star.significance_level
@@ -865,8 +890,13 @@ for(allel.num in 1:length(allels)){
 					p.values.above_star_level_norm[i] <- 0
 				}
 			}
+			vert_lines <- which(p.values.above_star_level_norm > 0)
+			for (sp in 1:length(vert_lines)){
+				abline(v=vert_lines[sp], col = "gray60", lty=2)
+			}
 			lines(p.values.above_sig_level_norm, type="p", col = "red", pch=20) #points above a certain significance level
 			lines(p.values.above_star_level_norm, type="p", col = "red", pch=8) #stars above a certain significance level
+
 			all.pvals<-c(all.pvals,p.values.norm)
 			aa.all_level <- cbind(aa.all_level, aa_level)
 			all.aas <- cbind(all.aas, aa_values_m)
@@ -877,15 +907,16 @@ for(allel.num in 1:length(allels)){
 			all.odds <- cbind(all.odds, odds.ratio.all)
 			above.star.all <- cbind(above.star.all, p.values.above_star_level_norm)
 			all.stattest <- cbind(all.stattest, stattest)
-		}
+#		}
   	}
 }
-
-if (statistical_correction == "Bayes"){
-	all.pvals.corrected <- all.pvals
-}else{
-	all.pvals.corrected <- p.adjust(all.pvals, method = statistical_correction)
-}
+		####BAYES - NOT AVAILABLE YET
+#if (statistical_correction == "Bayes"){
+#	all.pvals.corrected <- all.pvals
+#}else{
+	corrected.p_values <- p.adjust(p.values.all[,1], method = statistical_correction)
+	all.pvals.corrected <- corrected.p_values[which(p.values.all[,2] == "min")]
+#}
 
 #forth: write this epitope in a csv
 all.pos.epi <- subset(pos.epi.matrix, !duplicated(pos.epi.matrix))
@@ -896,16 +927,16 @@ if (nrow(all.pos.epi)>1){
 	#print(all.pos.epi)
 }
 
-####BAYES
-if (statistical_correction == "Bayes"){	
-	result_output <- (matrix(all.pvals, ncol=sum(allels.count>patnum.threshold), dimnames=list(1:length(probs.max),allels[allels.count>patnum.threshold])))
-
-	all.pvals.c_output <- (matrix(all.pvals.corrected, ncol=sum(allels.count>patnum.threshold), dimnames=list(1:length(probs.max),allels[allels.count>patnum.threshold])))
-}else{
+		####BAYES - NOT AVAILABLE YET
+#if (statistical_correction == "Bayes"){	
+#	result_output <- (matrix(all.pvals, ncol=sum(allels.count>patnum.threshold), dimnames=list(1:length(probs.max),allels[allels.count>patnum.threshold])))
+#
+#	all.pvals.c_output <- (matrix(all.pvals.corrected, ncol=sum(allels.count>patnum.threshold), dimnames=list(1:length(probs.max),allels[allels.count>patnum.threshold])))
+#}else{
 	result_output <- (matrix(all.pvals, ncol=sum(allels.count>patnum.threshold), dimnames=list(1:length(p.values.min),allels[allels.count>patnum.threshold])))
 
 	all.pvals.c_output <- (matrix(all.pvals.corrected, ncol=sum(allels.count>patnum.threshold), dimnames=list(1:length(p.values.min),allels[allels.count>patnum.threshold])))
-}
+#}
 
 result <- c()
 
@@ -917,41 +948,41 @@ if (!is.null(reference_sequence) && !(reference_sequence == "") ){
 	}
 }
 
-####BAYES
-if (statistical_correction == "Bayes"){	
-	if (!is.null(reference_sequence) && !(reference_sequence == "") ){
-		if (is.null(dim(all.aas))){
-			result <- cbind(result_output, all.aas, all.stattest, as.character(subseq(ref_seq, j, j)))
-		}
-		else {	
-			for (i in 1:ncol(result_output)){
-				result <- cbind(result, result_output[,i], scale(result_output[,i],center=TRUE,scale=TRUE)[,1], all.aas[,i], all.stattest[,i], ref_row)
-			}
-		}
-	}else{
-		if (is.null(dim(all.aas))){
-			result <- cbind(result_output, all.aas, all.stattest)
-		}
-		else {	
-			for (i in 1:ncol(result_output)){
-				result <- cbind(result, result_output[,i], scale(result_output[,i],center=TRUE,scale=TRUE)[,1], all.aas[,i], all.stattest[,i])
-			}
-		}
-
-
-	}
-
-	colname <- c()
-	if (!is.null(reference_sequence) && !(reference_sequence == "") ){
-		for (i in 1:(ncol(result)/5)){
-			colname <- c(colname, allels[allels.count>patnum.threshold][i], "z-scores", "AA with lowest p value", "Wilcox", "ref_seq")
-		}
-	}else{
-		for (i in 1:(ncol(result)/4)){
-			colname <- c(colname, allels[allels.count>patnum.threshold][i], "z-scores", "AA with lowest p value", "Wilcox")
-		}
-	}
-}else{
+		####BAYES - NOT AVAILABLE YET
+#if (statistical_correction == "Bayes"){	
+#	if (!is.null(reference_sequence) && !(reference_sequence == "") ){
+#		if (is.null(dim(all.aas))){
+#			result <- cbind(result_output, all.aas, all.stattest, as.character(subseq(ref_seq, j, j)))
+#		}
+#		else {	
+#			for (i in 1:ncol(result_output)){
+#				result <- cbind(result, result_output[,i], scale(result_output[,i],center=TRUE,scale=TRUE)[,1], all.aas[,i], all.stattest[,i], ref_row)
+#			}
+#		}
+#	}else{
+#		if (is.null(dim(all.aas))){
+#			result <- cbind(result_output, all.aas, all.stattest)
+#		}
+#		else {	
+#			for (i in 1:ncol(result_output)){
+#				result <- cbind(result, result_output[,i], scale(result_output[,i],center=TRUE,scale=TRUE)[,1], all.aas[,i], all.stattest[,i])
+#			}
+#		}
+#
+#
+#	}
+#
+#	colname <- c()
+#	if (!is.null(reference_sequence) && !(reference_sequence == "") ){
+#		for (i in 1:(ncol(result)/5)){
+#			colname <- c(colname, allels[allels.count>patnum.threshold][i], "z-scores", "AA with lowest p value", "Wilcox", "ref_seq")
+#		}
+#	}else{
+#		for (i in 1:(ncol(result)/4)){
+#			colname <- c(colname, allels[allels.count>patnum.threshold][i], "z-scores", "AA with lowest p value", "Wilcox")
+#		}
+#	}
+#}else{
 
 	if (!is.null(reference_sequence) && !(reference_sequence == "") ){
 		if (is.null(dim(all.aas))){
@@ -974,17 +1005,17 @@ if (statistical_correction == "Bayes"){
 
 
 	}
-}
+#}
 
 colname <- c()
 
 if (!is.null(reference_sequence) && !(reference_sequence == "") ){
 	for (i in 1:(ncol(result)/7)){
-		colname <- c(colname, allels[allels.count>patnum.threshold][i],"Corrected p-value", "z-scores", "AA with lowest p value", "Odd-ratio", "Wilcox", "ref_seq")
+		colname <- c(colname, allels[allels.count>patnum.threshold][i],"Corrected p-value", "z-scores", "AA with lowest p value", "Odds ratio", "Wilcox", "ref_seq")
 	}
 }else{
 	for (i in 1:(ncol(result)/6)){
-		colname <- c(colname, allels[allels.count>patnum.threshold][i],"Corrected p-value", "z-scores", "AA with lowest p value", "Odd-ratio", "Wilcox")
+		colname <- c(colname, allels[allels.count>patnum.threshold][i],"Corrected p-value", "z-scores", "AA with lowest p value", "Odds ratio", "Wilcox")
 	}
 }
 
@@ -1008,14 +1039,12 @@ return (result)
 #"../inst/extdata/Example_aa.fasta",
 #"../inst/extdata/Example_epitopes_aa.csv",
 #"../inst/extdata/Example_HLA_binding_motifs_aa.csv",
-#save_name = "epitope_results.pdf",
+#save_name_pdf = "epitope_results.pdf",
 #save_name_csv = "epitope_results.csv",
 #dna = FALSE,
-#patnum.threshold = 1,
-#optical.significance_level = 0.01, 
-#star.significance_level = 0.5,
-#pot.epitope_level = 0.01,
-#window_threshold = 0.01,
+#patnum_threshold = 1,
+#optical_significance_level = 0.01, 
+#star_significance_level = 0.5,
 #A11 = 10,
 #A12 = 11,
 #A21 = 13,
@@ -1024,9 +1053,11 @@ return (result)
 #B12 = 18,
 #B21 = 20,
 #B22 = 21,
-#statistical_correction = "none",
-#with_phylogenetic_comparison = TRUE,
+#multiple_testing_correction = "none",
+#phylo_bias_check = TRUE,
 #matrix_for_phylo = "BLOSUM62",
-#reference_sequence = "../inst/extdata/Example_reference_aa.fasta",
-#one_ident=FALSE
+#path_to_file_reference_sequence = "../inst/extdata/Example_reference_aa.fasta",
+#one_feature=FALSE,
+#window_size=9,
+#epi_plot=TRUE
 #)
